#cs ----------------------------------------------------------------------------

	AutoIt Version: 3.3.12.0
	Author:         Jie Shen

	Script Function:
	Run an exported HCI^2 Framework system and wait until it stops
	Command-line parameters required:
	1. [Optional] Path of the exported system's system controller programme.
	If a path is not given, the script will try to find and use the exe
	file having the same file title and parent directory as the script.
	2. [Optional] Waiting time, in ms, before the first time to check whether
	the system is still running. The default value is 1000.

#ce ----------------------------------------------------------------------------

#include-once
#include <WinAPI.au3>
#include <WinAPIProc.au3>
#include <WinAPIFiles.au3>
#include "Utilities.au3"

main()
Exit

Func main()

	; Preparation
	Local $nWaitingTime = 1000
	Local $szSystemController = ""
	If $CmdLine[0] >= 1 Then
		$szSystemController = _WinAPI_GetFullPathName($CmdLine[1])
	Else
		$szSystemController = StringLeft(@ScriptFullPath, StringLen(@ScriptFullPath) - 3) & "exe"
	EndIf
	If $CmdLine[0] >= 2 Then
		$nWaitingTime = $CmdLine[0]
		If $nWaitingTime < 0 Then
			$nWaitingTime = 0
		EndIf
	EndIf
	Local $temp = StringSplit($szSystemController, "\/")
	Local $szWindowTitle = StringLeft($temp[$temp[0]], StringLen($temp[$temp[0]]) - 4)

	; Run the system
	Local $ProcInfo = RunEx('"' & $szSystemController & '"', 0, True)
	If $ProcInfo = 0 Then
		Return
	EndIf
	Local $dwProcId = _WinAPI_GetProcessID($ProcInfo[0]);
	$temp = DllCall("Kernel32.dll", "DWORD", "GetThreadId", "HANDLE", $ProcInfo[1])
	Local $dwThreadId = $temp[0]

	; Try to find the window
	Local $hMainWnd = 0
	Do
		Sleep(50)
		Local $arrWindows = WinList($szWindowTitle), $i = 0
		If $arrWindows[0][0] > 0 Then
			For $i = 1 To $arrWindows[0][0]
				Local $hWnd = $arrWindows[$i][1]
				If Not _WinAPI_IsWindowVisible($hWnd) Then
					ContinueLoop
				EndIf
				Local $dwWndProcId = 0, $dwWndThreadId = 0
				$dwWndThreadId = _WinAPI_GetWindowThreadProcessId($hWnd, $dwWndProcId)
				If $dwWndProcId = $dwProcId And $dwWndThreadId = $dwThreadId Then
					$hMainWnd = $hWnd
					ExitLoop
				EndIf
			Next
		EndIf
	Until _WinAPI_IsWindow($hMainWnd)

	; Sleep for a while
	If $nWaitingTime > 0 Then
		Sleep($nWaitingTime)
	EndIf

	; Wait until the system stops
	While _WinAPI_IsWindow($hMainWnd)
		If _WinAPI_GetWindowText($hMainWnd) = $szWindowTitle Then
			ExitLoop
		EndIf
		Sleep(50)
	WEnd

	; Close the system controller
	While _WinAPI_IsWindow($hMainWnd)
		ClosePopupWindows($hMainWnd)
		_WinAPI_PostMessage($hMainWnd, 0x0010, 0, 0)
		Sleep(50)
	WEnd

	; Wait for the system controller process to stop
	_WinAPI_WaitForSingleObject($ProcInfo[0], -1)

	; Clean up
	_WinAPI_CloseHandle($ProcInfo[0])
	$ProcInfo[0] = 0
	_WinAPI_CloseHandle($ProcInfo[1])
	$ProcInfo[1] = 0

EndFunc   ;==>main
